@@ -109,6 +109,10 @@ describe("path_temp", {
 })
 
 describe("path_ext", {
+  it ("returns 0 length outputs for 0 length inputs", {
+    expect_equal(path_ext(character()), character())
+  })
+
   it ("returns the path extension, or \"\" if one does not exist", {
     expect_equal(path_ext("foo.bar"), "bar")
     expect_equal(path_ext("foo.boo.bar"), "bar")
@@ -269,7 +273,7 @@ describe("path_common", {
 
 # derived from https://github.com/python/cpython/blob/6f0eb93183519024cb360162bdd81b9faec97ba6/Lib/test/test_posixpath.py#L483
 describe("path_rel", {
-  it("works for posix paths", {
+  it("works for POSIX paths", {
     cur_dir <- path_file(getwd())
     expect_equal(path_rel("a"), "a")
     expect_equal(path_rel(path_abs("a")), "a")
@@ -308,6 +312,12 @@ describe("path_rel", {
   })
 })
 
+describe("path_abs", {
+  it("uses the start parameter", {
+    expect_equal(path_abs("b", "a"), path_abs("a/b"))
+  })
+})
+
 describe("path_home", {
   # The trailing slash is needed to ensure we get path expansion
   # on POSIX systems when readline support is not built in. (#60)
